pub struct OnionCodec {
pub codec: ErasedDynCodec,
pub version: StaticCodecVersion<1, 0, 0>,
}Expand description
Onion identity meta-codec which wraps an existing codec and passes the inputs and outputs unchanged to and from this codec during encoding and decoding.
Fields
codec: ErasedDynCodecThe configuration of the wrapped codec.
version: StaticCodecVersion<1, 0, 0>The codec’s encoding format version. Do not provide this parameter explicitly.